@@ -32,11 +32,20 @@ impl Query {
 
         if self.interactive {
             let mut fzf = Fzf::new(false)?;
-            while let Some(dir) = stream.next() {
-                writeln!(fzf.stdin(), "{}", dir.display_score(now)).pipe_exit("fzf")?;
-            }
+            let stdin = fzf.stdin();
+
+            let selection = loop {
+                let dir = match stream.next() {
+                    Some(dir) => dir,
+                    None => break fzf.select()?,
+                };
+
+                match writeln!(stdin, "{}", dir.display_score(now)) {
+                    Err(e) if e.kind() == io::ErrorKind::BrokenPipe => break fzf.select()?,
+                    result => result.context("could not write to fzf")?,
+                }
+            };
 
-            let selection = fzf.wait_select()?;
             if self.score {
                 print!("{}", selection);
             } else {
