@@ -1,14 +1,14 @@
-use crate::db::Epoch;
+use std::env;
+use std::path::{Component, Path, PathBuf};
+use std::process::Command;
+use std::time::SystemTime;
 
 use anyhow::{bail, Context, Result};
 
-use std::env;
-use std::path::{Component, Path, PathBuf};
-use std::time::SystemTime;
+use crate::db::Epoch;
 
 pub fn canonicalize<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
-    dunce::canonicalize(path)
-        .with_context(|| format!("could not resolve path: {}", path.as_ref().display()))
+    dunce::canonicalize(path).with_context(|| format!("could not resolve path: {}", path.as_ref().display()))
 }
 
 pub fn current_dir() -> Result<PathBuf> {
@@ -16,24 +16,48 @@ pub fn current_dir() -> Result<PathBuf> {
 }
 
 pub fn current_time() -> Result<Epoch> {
-    let current_time = SystemTime::now()
-        .duration_since(SystemTime::UNIX_EPOCH)
-        .context("system clock set to invalid time")?
-        .as_secs();
+    let current_time =
+        SystemTime::now().duration_since(SystemTime::UNIX_EPOCH).context("system clock set to invalid time")?.as_secs();
 
     Ok(current_time)
 }
 
+/// Constructs a new [`Command`] for launching the program with the name
+/// `program`.
+///
+/// On Windows, CreateProcess implicitly searches the current working directory
+/// for the executable, which is a potential security issue. Instead, we resolve
+/// the path to the executable and then pass it to CreateProcess.
+///
+/// On other platforms, this is a no-op.
+///
+pub fn get_command<P: AsRef<Path>>(program: P) -> Result<Command> {
+    let program = program.as_ref();
+    if !cfg!(windows) {
+        return Ok(Command::new(program));
+    }
+
+    let paths = env::var_os("PATH").context("PATH environment variable not set")?;
+    for path in env::split_paths(&paths) {
+        if path.as_os_str().is_empty() {
+            continue;
+        }
+        let path = path.join(program);
+        if path.metadata().map_or(false, |m| !m.is_dir()) {
+            return Ok(Command::new(path));
+        }
+    }
+
+    bail!("executable not found in PATH: {}", program.display());
+}
+
 pub fn path_to_str<P: AsRef<Path>>(path: &P) -> Result<&str> {
     let path = path.as_ref();
     path.to_str().with_context(|| format!("invalid unicode in path: {}", path.display()))
 }
 
-/// Resolves the absolute version of a path.
-///
-/// If path is already absolute, the path is still processed to be cleaned, as it can contained ".." or "." (or other)
-/// character.
-/// If path is relative, use the current directory to build the absolute path.
+/// Returns the absolute version of a path. Like [`std::path::Path::canonicalize`], but doesn't
+/// resolve symlinks.
 pub fn resolve_path<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
     let path = path.as_ref();
     let base_path;
@@ -51,9 +75,7 @@ pub fn resolve_path<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
 
             match components.next() {
                 Some(Component::Prefix(prefix)) => match prefix.kind() {
-                    Prefix::Disk(drive_letter) | Prefix::VerbatimDisk(drive_letter) => {
-                        Some(drive_letter)
-                    }
+                    Prefix::Disk(drive_letter) | Prefix::VerbatimDisk(drive_letter) => Some(drive_letter),
                     _ => None,
                 },
                 _ => None,
@@ -106,9 +128,8 @@ pub fn resolve_path<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
                 components.next();
 
                 let current_dir = env::current_dir()?;
-                let drive_letter = get_drive_letter(&current_dir).with_context(|| {
-                    format!("could not get drive letter: {}", current_dir.display())
-                })?;
+                let drive_letter = get_drive_letter(&current_dir)
+                    .with_context(|| format!("could not get drive letter: {}", current_dir.display()))?;
                 base_path = get_drive_path(drive_letter);
                 stack.extend(base_path.components());
             }
@@ -141,7 +162,7 @@ pub fn resolve_path<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
     Ok(stack.iter().collect())
 }
 
-// Convert a string to lowercase, with a fast path for ASCII strings.
+/// Convert a string to lowercase, with a fast path for ASCII strings.
 pub fn to_lowercase<S: AsRef<str>>(s: S) -> String {
     let s = s.as_ref();
     if s.is_ascii() {
